/** 
 * ************************************************************************
 *                                DelaySim                                                               *
 * ************************************************************************
 *  Software package to simulate systems with delays described in the Ph.D. 
 *  thesis
 *  
 *  	"Formal Modeling and Simulation of Biological Systems With Delays" 
 *  
 *  by G.Caravagna, Ph.D. student in Computer Science at the University of 
 *  Pisa, Italy.
 *  
 *  Copyright (C) 2011,  Giulio Caravagna [caravagn@di.unipi.it]
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>. 
**/

package DelaySim;

/**
 * A class describing entries in the scheduling lists of the simulation algorithms. 
 * An entry is described by the time of the associated event, and the index of the
 * reaction involved in the event.
 * 
 * @author Giulio Caravagna 
 */
public class Entry  implements Comparable<Entry>
{
	/**
	 * time of the event
	 */
	public double time;
	
	/**
	 * reaction involved in the event
	 */
	public int idx;	

	/**
	 * Create an event-object happening at time 'time' and involving reaction
	 * 'reaction'
	 * @param time the time of the event
	 * @param reaction the reaction involved
	 */
	public Entry(double time, int reaction) { this.time = time; idx = reaction; }
		
	/**
	 * compare two Entry objects on their 'time' value
	 */
	public int compareTo(Entry o) { if(this.time - o.time > 0.0) return 1; else return -1; }
	 
	/**
	 * Return a string representation of this event
	 */
	public String toString(){ return "("+(new String(""+time)).substring(0, Math.min(5, (""+time).length()))+", "+idx+")"; }
}
