/** 
 * ************************************************************************
 *                                DelaySim                                                               *
 * ************************************************************************
 *  Software package to simulate systems with delays described in the Ph.D. 
 *  thesis
 *  
 *  	"Formal Modeling and Simulation of Biological Systems With Delays" 
 *  
 *  by G.Caravagna, Ph.D. student in Computer Science at the University of 
 *  Pisa, Italy.
 *  
 *  Copyright (C) 2011,  Giulio Caravagna [caravagn@di.unipi.it]
 *  
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>. 
**/
package DelaySim.examples;

import DelaySim.DDA;
import DelaySim.PDA;
import DelaySim.Reaction;

/**
* A two-reactions system. 
* 
* @author Giulio Caravagna 
*/
public class TwoReactionsExample {

	/*
	 * Change this to change the initial state vector
	 */
	public static int INITAL_A_MOLECULES = 3;
	public static int INITAL_B_MOLECULES = 5;

	public static void main(String[] args) 
	{
		/* The reversible reaction is
		 *  
		 *  	A->B   (B->A)
		 *  
		 *  with kinetic constants 10.0 and 1.0 and delays 3 and 5
		 */
		int [] v1_R = {-1, 0}; 
		int [] v1_P = {0, 1};   
		Reaction r1 = new Reaction("R1", v1_R, v1_P, 10.0, 3.0);

		int [] v2_R = {0, -1}; 
		int [] v2_P = {1, 0};   
		Reaction r2 = new Reaction("R2", v2_R, v2_P, 1.0, 5.0);

		/*
		 *  The initial state is
		 *  
		 *  	X(t0) = ( nA, NB )
		 *  
		 *  where nA=INITAL_A_MOLECULES and nB=INITAL_B_MOLECULES.
		 */				
		int [] x0 = {INITAL_A_MOLECULES, INITAL_B_MOLECULES};
		
		/*
		 *  The set of all the reactions in this system
		 */
		Reaction [] reactions = {r1, r2};
		
		/*
		 * The DDA system 
		 */
		DDA DDA_system = new DDA(reactions, x0);		
		DDA_system.print();
		
		/*
		 * A DDA simulation starting at time t0 = 0 and going for 10 time units
		 */
		DDA_system.simulate(0, 10);
		

		/*
		 * The PDA system 
		 */
		PDA PDA_system = new PDA(reactions, x0);		
		PDA_system.print();
		
		/*
		 * A DDA simulation starting at time t0 = 0 and going for 10 time units
		 */
		PDA_system.simulate(0, 10);
	}

}
